@@ -3,7 +3,7 @@
 # The copyright notice and plain old documentation (POD)
 # are at the end of this file.
 #
-package  Test::STDmaker::tgB1;
+package  t::Test::STDmaker::tgB1;
 
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
 $VERSION = '0.01';
-$DATE = '2003/06/14';
+$DATE = '2004/04/09';
 $FILE = __FILE__;
 
 ########
@@ -39,21 +39,30 @@ STD2167_Template: ^
 Version: 0.01^
 Classification: None^
 Temp: temp.pl^
-Demo: tg1B.d^
-Verify: tg1B.t^
+Demo: tgB1.d^
+Verify: tgB1.t^
 
 
  T: 2^
 
+ C: 
+    #########
+    # For "TEST" 1.24 or greater that have separate std err output,
+    # redirect the TESTERR to STDOUT
+    #
+    tech_config( 'Test.TESTERR', \*STDOUT );   
+^  
+
+
  R: L<Test::STDmaker::tg1/capability-A [1]>^
  C: my $x = 2^
  C: my $y = 3^
  A: $x + $y^
-SE: '5'^
+SE: 5^
 ok: 1^
 
- A: ($x+$y,$y-$x)^
- E: '5','1'^
+ A: [($x+$y,$y-$x)]^
+ E: [5,2]^
 ok: 2^
 
 
